==> 0.0.4.tar.gz: lib/fealm/Fealm.dart <==
import 'package:sqflite/sqflite.dart';
import 'package:sqflite/sqlite_api.dart';
import 'package:path/path.dart';

import 'FealmObject.dart';
import 'FealmQuery.dart';

class Fealm{

  static Fealm _instance;
  static String _database_name="fealm_db.db";
  static int _version=1;

  Database db;
  List<FealmObject> _queueList;

  Fealm.open(Database database) {
     this.db = database;
     this._queueList = List();
     Fealm._instance = this;
  }

  static Fealm getInstance(){
    return Fealm._instance;
  }

  void copyToFealmOrUpdate(FealmObject fealmObject){
     _queueList.add(fealmObject);
  }

  static Future<Database> init() async{
    var databasesPath = await getDatabasesPath();
    var path = join(databasesPath,_database_name);
    return openDatabase(path, version: _version);
  }


  void commit() async{

      if(db!=null) {
        for (FealmObject fealmObject in _queueList) {
          var tableInfo = await db.rawQuery(
              "pragma table_info(" + fealmObject.getModelName() + ")");
          Map<String, String> tableMap = Map();
          for (var column in tableInfo)
            tableMap[column['name']] = column['type'];

          if (!_isMigrationNotRequired(
              convertDBType(fealmObject.convertType()), tableMap)) {
            await db.rawQuery(
                "DROP TABLE IF EXISTS " + fealmObject.getModelName());
            await db.execute(_buildCreateQuery(
                convertDBType(fealmObject.convertType()),
                fealmObject.getModelName()));
          }
          print(fealmObject.getId());

          List records = await db.query(
              fealmObject.getModelName(), where: "id = ?",
              whereArgs: [fealmObject.getId()]);
          if (records.length == 0) {
            await db.insert(fealmObject.getModelName(), fealmObject.toJson(),
                conflictAlgorithm: ConflictAlgorithm.replace);
            print("Create....");
          }
          else {
            var update = await db.update(
                fealmObject.getModelName(), fealmObject.toJson(),
                where: "id = ?",
                whereArgs: [fealmObject.getId()],
                conflictAlgorithm: ConflictAlgorithm.replace);
            print("Update....");
            print(update);
          }
        }
      }
  }


  void deleteFromFealm(FealmObject fealmObject) async{
    var databasesPath = await getDatabasesPath();
    var path = join(databasesPath,_database_name);
    Database db = await openDatabase(path, version: _version);
    await db.delete(fealmObject.getModelName(),where: "id = ?",whereArgs: [fealmObject.getId()]);
  }


  FealmQuery where(FealmObject fealmObject){
    return FealmQuery.where(fealmObject);
  }

  bool _isMigrationNotRequired(Map<String,String> modelMap,Map<String,String> tableMap){
    if(modelMap.entries.length!=tableMap.entries.length)
      return false;
    for(var c in modelMap.entries){
      if(tableMap.containsKey(c.key) && c.value == tableMap[c.key])
        continue;
      return false;
    }
    return true;
  }

  String _buildCreateQuery(Map<String,String> map,String tableName){
    var buffer = new StringBuffer();
    buffer.write("CREATE TABLE IF NOT EXISTS ");
    buffer.write(tableName);
    buffer.write("( id INTEGER PRIMARY KEY");
    for(var en in map.entries) {
      if(en.key != 'id')
         buffer.write("," + en.key + " " + (en.value));
    }
    buffer.write(")");
    return buffer.toString();
  }

  Map<String,String> convertDBType(Map<String,Type> map){
    Map<String,String> m = Map();
    for(var c in map.entries){
      if(c.value.toString() == "String")
        m[c.key] = 'TEXT';
      else if(c.value.toString() == "int")
        m[c.key] = 'INTEGER';
      else if(c.value.toString() == "bool")
        m[c.key] = 'TINYINT';
    }
    return m;
  }

}

==> 0.0.6.tar.gz: lib/fealm/Fealm.dart <==
import 'package:sqflite/sqflite.dart';
import 'package:sqflite/sqlite_api.dart';
import 'package:path/path.dart';

import 'FealmObject.dart';
import 'FealmQuery.dart';

class Fealm{

  static Fealm _instance;
  static String _database_name="fealm_db.db";
  static int _version=1;

  Database db;
  List<FealmObject> _queueList;

  Fealm.open(Database database) {
     this.db = database;
     this._queueList = List();
     Fealm._instance = this;
  }

  static Fealm getInstance(){
    return Fealm._instance;
  }

  void copyToFealmOrUpdate(FealmObject fealmObject){
     _queueList.add(fealmObject);
  }

  static Future<Database> init() async{
    var databasesPath = await getDatabasesPath();
    var path = join(databasesPath,_database_name);
    return openDatabase(path, version: _version);
  }


  void commit() async{

      if(db!=null) {
        for (FealmObject fealmObject in _queueList) {
          var tableInfo = await db.rawQuery(
              "pragma table_info(" + fealmObject.getModelName() + ")");
          Map<String, String> tableMap = Map();
          for (var column in tableInfo)
            tableMap[column['name']] = column['type'];

          if (!_isMigrationNotRequired(
              convertDBType(fealmObject.convertType()), tableMap)) {
            await db.rawQuery(
                "DROP TABLE IF EXISTS " + fealmObject.getModelName());
            await db.execute(_buildCreateQuery(
                convertDBType(fealmObject.convertType()),
                fealmObject.getModelName()));
          }
          print(fealmObject.getId());

          List records = await db.query(
              fealmObject.getModelName(), where: "id = ?",
              whereArgs: [fealmObject.getId()]);
          if (records.length == 0) {
            await db.insert(fealmObject.getModelName(), fealmObject.toJson(),
                conflictAlgorithm: ConflictAlgorithm.replace);
            print("Create....");
          }
          else {
            var update = await db.update(
                fealmObject.getModelName(), fealmObject.toJson(),
                where: "id = ?",
                whereArgs: [fealmObject.getId()],
                conflictAlgorithm: ConflictAlgorithm.replace);
            print("Update....");
            print(update);
          }
        }
      }
  }


  void deleteFromFealm(FealmObject fealmObject) async{
    var databasesPath = await getDatabasesPath();
    var path = join(databasesPath,_database_name);
    Database db = await openDatabase(path, version: _version);
    await db.delete(fealmObject.getModelName(),where: "id = ?",whereArgs: [fealmObject.getId()]);
  }


  FealmQuery where(FealmObject fealmObject){
    return FealmQuery.where(db,fealmObject);
  }

  bool _isMigrationNotRequired(Map<String,String> modelMap,Map<String,String> tableMap){
    if(modelMap.entries.length!=tableMap.entries.length)
      return false;
    for(var c in modelMap.entries){
      if(tableMap.containsKey(c.key) && c.value == tableMap[c.key])
        continue;
      return false;
    }
    return true;
  }

  String _buildCreateQuery(Map<String,String> map,String tableName){
    var buffer = new StringBuffer();
    buffer.write("CREATE TABLE IF NOT EXISTS ");
    buffer.write(tableName);
    buffer.write("( id INTEGER PRIMARY KEY");
    for(var en in map.entries) {
      if(en.key != 'id')
         buffer.write("," + en.key + " " + (en.value));
    }
    buffer.write(")");
    return buffer.toString();
  }

  Map<String,String> convertDBType(Map<String,Type> map){
    Map<String,String> m = Map();
    for(var c in map.entries){
      if(c.value.toString() == "String")
        m[c.key] = 'TEXT';
      else if(c.value.toString() == "int")
        m[c.key] = 'INTEGER';
      else if(c.value.toString() == "bool")
        m[c.key] = 'TINYINT';
    }
    return m;
  }

}
